#
# PySNMP MIB module DLSW-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DLSW-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:08:34 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint", "SingleValueConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( sdlcLSAddress, ) = mibBuilder.importSymbols("SNA-SDLC-MIB", "sdlcLSAddress")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( MibIdentifier, Bits, mib_2, Gauge32, ObjectIdentity, ModuleIdentity, Counter32, Unsigned32, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, Integer32, TimeTicks, NotificationType, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "Bits", "mib-2", "Gauge32", "ObjectIdentity", "ModuleIdentity", "Counter32", "Unsigned32", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "Integer32", "TimeTicks", "NotificationType", "iso")
( RowPointer, TruthValue, TextualConvention, DisplayString, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowPointer", "TruthValue", "TextualConvention", "DisplayString", "RowStatus")
dlsw = ModuleIdentity((1, 3, 6, 1, 2, 1, 46))
if mibBuilder.loadTexts: dlsw.setLastUpdated('9606040900Z')
if mibBuilder.loadTexts: dlsw.setOrganization('AIW DLSw MIB RIGLET and IETF DLSw MIB Working Group')
if mibBuilder.loadTexts: dlsw.setContactInfo('David D. Chen\n                   IBM Corporation\n                   800 Park, Highway 54\n                   Research Triangle Park, NC 27709-9990\n                   Tel:    1 919 254 6182\n                   E-mail: dchen@vnet.ibm.com')
if mibBuilder.loadTexts: dlsw.setDescription('This MIB module contains objects to manage Data Link\n         Switches.')
dlswMIB = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1))
dlswDomains = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 2))
class NBName(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,16)

class MacAddressNC(OctetString, TextualConvention):
    displayHint = '1x:'
    subtypeSpec = OctetString.subtypeSpec+ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(6,6),)
class TAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

class EndStationLocation(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("other", 1), ("internal", 2), ("remote", 3), ("local", 4),)

class DlcType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("other", 1), ("na", 2), ("llc", 3), ("sdlc", 4), ("qllc", 5),)

class LFSize(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(516, 635, 754, 873, 993, 1112, 1231, 1350, 1470, 1542, 1615, 1688, 1761, 1833, 1906, 1979, 2052, 2345, 2638, 2932, 3225, 3518, 3812, 4105, 4399, 4865, 5331, 5798, 6264, 6730, 7197, 7663, 8130, 8539, 8949, 9358, 9768, 10178, 10587, 10997, 11407, 12199, 12992, 13785, 14578, 15370, 16163, 16956, 17749, 20730, 23711, 26693, 29674, 32655, 38618, 41600, 44591, 47583, 50575, 53567, 56559, 59551, 65535,))
    namedValues = NamedValues(("lfs516", 516), ("lfs635", 635), ("lfs754", 754), ("lfs873", 873), ("lfs993", 993), ("lfs1112", 1112), ("lfs1231", 1231), ("lfs1350", 1350), ("lfs1470", 1470), ("lfs1542", 1542), ("lfs1615", 1615), ("lfs1688", 1688), ("lfs1761", 1761), ("lfs1833", 1833), ("lfs1906", 1906), ("lfs1979", 1979), ("lfs2052", 2052), ("lfs2345", 2345), ("lfs2638", 2638), ("lfs2932", 2932), ("lfs3225", 3225), ("lfs3518", 3518), ("lfs3812", 3812), ("lfs4105", 4105), ("lfs4399", 4399), ("lfs4865", 4865), ("lfs5331", 5331), ("lfs5798", 5798), ("lfs6264", 6264), ("lfs6730", 6730), ("lfs7197", 7197), ("lfs7663", 7663), ("lfs8130", 8130), ("lfs8539", 8539), ("lfs8949", 8949), ("lfs9358", 9358), ("lfs9768", 9768), ("lfs10178", 10178), ("lfs10587", 10587), ("lfs10997", 10997), ("lfs11407", 11407), ("lfs12199", 12199), ("lfs12992", 12992), ("lfs13785", 13785), ("lfs14578", 14578), ("lfs15370", 15370), ("lfs16163", 16163), ("lfs16956", 16956), ("lfs17749", 17749), ("lfs20730", 20730), ("lfs23711", 23711), ("lfs26693", 26693), ("lfs29674", 29674), ("lfs32655", 32655), ("lfs38618", 38618), ("lfs41600", 41600), ("lfs44591", 44591), ("lfs47583", 47583), ("lfs50575", 50575), ("lfs53567", 53567), ("lfs56559", 56559), ("lfs59551", 59551), ("lfs65535", 65535),)

null = MibIdentifier((0, 0))
dlswTCPDomain = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 2, 1))
class DlswTCPAddress(OctetString, TextualConvention):
    displayHint = '1d.1d.1d.1d'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

dlswNode = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 1))
dlswTConn = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 2))
dlswInterface = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 3))
dlswDirectory = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 4))
dlswCircuit = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 5))
dlswSdlc = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 6))
dlswNodeVersion = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,2)).setFixedLength(2)).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswNodeVersion.setDescription('This value identifies the particular version of the DLSw\n        standard supported by this DLSw.  The first octet is a\n        hexadecimal value representing the DLSw standard Version\n        number of this DLSw, and the second is a hexadecimal value\n        representing the DLSw standard Release number. This\n        information is reported in DLSw Capabilities Exchange.')
dlswNodeVendorID = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(3,3)).setFixedLength(3)).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswNodeVendorID.setDescription("The value identifies the manufacturer's IEEE-assigned\n        organizationally Unique Identifier (OUI) of this DLSw.\n        This information is reported in DLSw Capabilities\n        Exchange.")
dlswNodeVersionString = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswNodeVersionString.setDescription('This string gives product-specific information about\n        this DLSw (e.g., product name, code release and fix level).\n        This flows in Capabilities Exchange messages.')
dlswNodeStdPacingSupport = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("none", 1), ("adaptiveRcvWindow", 2), ("fixedRcvWindow", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswNodeStdPacingSupport.setDescription('Circuit pacing, as defined in the DLSw Standard, allows each\n        of the two DLSw nodes on a circuit to control the amount\n        of data the other is permitted to send to them.  This object\n        reflects the level of support the DLSw node has for this\n        protocol.  (1) means the node has no support for the standard\n        circuit pacing flows;  it may use RFC 1434+ methods only, or\n        a proprietary flow control scheme.  (2) means the node supports\n        the standard scheme and can vary the window sizes it grants as\n        a data receiver.  (3) means the node supports the standard\n        scheme but never varies its receive window size.')
dlswNodeStatus = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("active", 1), ("inactive", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswNodeStatus.setDescription('The status of the DLSw part of the system.  Changing the\n        value from active to inactive causes DLSw to take\n        the following actions - (1) it disconnects all circuits\n        through all DLSw partners, (2) it disconnects all\n        transport connections to all DLSw partners, (3) it\n        disconnects all local DLC connections, and (4) it stops\n        processing all DLC connection set-up traffic.\n        Since these are destructive actions, the user should\n        query the circuit and transport connection tables in\n        advance to understand the effect this action will have.\n        Changing the value from inactive to active causes DLSw\n        to come up in its initial state, i.e., transport\n        connections established and ready to bring up circuits.')
dlswNodeUpTime = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 6), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswNodeUpTime.setDescription('The amount of time (in hundredths of a second) since\n        the DLSw portion of the system was last re-initialized.\n        That is, if dlswState is in the active state,\n        the time the dlswState entered the active state.\n        It will remain zero if dlswState is in the\n        inactive state.')
dlswNodeVirtualSegmentLFSize = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 7), LFSize().clone('lfs65535')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswNodeVirtualSegmentLFSize.setDescription('The largest frame size (including DLC header and info field\n        but not any MAC-level or framing octets) this DLSw can forward\n        on any path through itself.  This object can represent any box-\n        level frame size forwarding restriction (e.g., from the use\n        of fixed-size buffers).  Some DLSw implementations will have\n        no such restriction.\n\n        This value will affect the LF size of circuits during circuit\n        creation.  The LF size of an existing circuit can be found in\n\n        the RIF (Routing Information Field).')
dlswNodeResourceNBExclusivity = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 8), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswNodeResourceNBExclusivity.setDescription('The value of true indicates that the NetBIOS Names\n        configured in dlswDirNBTable are the only ones accessible\n        via this DLSw.\n\n        If a node supports sending run-time capabilities exchange\n        messages, changes to this object should cause that action.\n        It is up to the implementation exactly when to start the\n        run-time capabilities exchange.')
dlswNodeResourceMacExclusivity = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 9), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswNodeResourceMacExclusivity.setDescription('The value of true indicates that the MAC addresses\n        configured in the dlswDirMacTable are the only ones\n        accessible via this DLSw.\n\n        If a node supports sending run-time capabilities exchange\n        messages, changes to this object should cause that action.\n        It is up to the implementation exactly when to start the\n        run-time capabilities exchange.')
dlswTConnStat = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 2, 1))
dlswTConnStatActiveConnections = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 2, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnStatActiveConnections.setDescription("The number of transport connections that are not in\n        `disconnected' state.")
dlswTConnStatCloseIdles = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnStatCloseIdles.setDescription('The number of times transport connections in this node\n        exited the connected state with zero active circuits on\n        the transport connection.')
dlswTConnStatCloseBusys = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnStatCloseBusys.setDescription('The number of times transport connections in this node\n        exited the connected state with some non-zero number\n        of active circuits on the transport connection.  Normally\n        this means the transport connection failed unexpectedly.')
dlswTConnConfigTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 2, 2), )
if mibBuilder.loadTexts: dlswTConnConfigTable.setDescription("This table defines the transport connections\n        that will be initiated or accepted by this\n        DLSw.  Structure of masks allows wildcard\n        definition for a collection of transport\n        connections by a conceptual row.  For a\n        specific transport connection, there may\n\n        be multiple of conceptual rows match the\n        transport address.  The `best' match will\n        the one to determine the characteristics\n        of the transport connection.")
dlswTConnConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1), ).setIndexNames((0, "DLSW-MIB", "dlswTConnConfigIndex"))
if mibBuilder.loadTexts: dlswTConnConfigEntry.setDescription('Each conceptual row defines a collection of\n        transport connections.')
dlswTConnConfigIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)))
if mibBuilder.loadTexts: dlswTConnConfigIndex.setDescription('The index to the conceptual row of the table.\n        Negative numbers are not allowed.  There\n        are objects defined that point to conceptual\n        rows of this table with this index value.\n        Zero is used to denote that no corresponding\n        row exists.\n\n        Index values are assigned by the agent, and\n        should not be reused but should continue to\n        increase in value.')
dlswTConnConfigTDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 2), ObjectIdentifier()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigTDomain.setDescription('The object identifier which indicates the transport\n        domain of this conceptual row.')
dlswTConnConfigLocalTAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 3), TAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigLocalTAddr.setDescription('The local transport address for this conceptual row\n        of the transport connection definition.')
dlswTConnConfigRemoteTAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 4), TAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigRemoteTAddr.setDescription('The remote transport address.  Together with\n        dlswTConnConfigEntryType and dlswTConnConfigGroupDefinition,\n        the object instance of this conceptual row identifies a\n        collection of the transport connections that will be\n        either initiated by this DLSw or initiated by a partner\n        DLSw and accepted by this DLSw.')
dlswTConnConfigLastModifyTime = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 5), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnConfigLastModifyTime.setDescription('The time (in hundredths of a second) since the value of\n        any object in this conceptual row except for\n        dlswTConnConfigOpens was last changed.  This value\n        may be compared to dlswTConnOperConnectTime to\n        determine whether values in this row are completely\n        valid for a transport connection created using\n        this row definition.')
dlswTConnConfigEntryType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("individual", 1), ("global", 2), ("group", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigEntryType.setDescription("The object instance signifies the type of entry in the\n        associated conceptual row.  The value of `individual'\n        means that the entry applies to a specific partner DLSw\n        node as identified by dlswTConnConfigRemoteTAddr and\n        dlswTConnConfigTDomain.  The value of `global'\n        means that the entry applies to all partner DLSw nodes\n        of the TDomain.  The value of 'group' means that the entry\n        applies to a specific set of DLSw nodes in the TDomain.\n        Any group definitions are enterprise-specific and are pointed\n        to by dlswTConnConfigGroupDefinition.  In the cases of\n        `global' and `group', the value in dlswTConnConfigRemoteTAddr\n        may not have any significance.")
dlswTConnConfigGroupDefinition = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 7), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigGroupDefinition.setDescription("For conceptual rows of `individual' and `global' as\n        specified in dlswTConnConfigEntryType, the instance\n        of this object is  `0.0'.  For conceptual rows of\n        `group', the instance points to the specific\n        group definition.")
dlswTConnConfigSetupType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("activePersistent", 2), ("activeOnDemand", 3), ("passive", 4), ("excluded", 5),)).clone('passive')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigSetupType.setDescription('This value of the instance of a conceptual row\n        identifies the behavior of the collection of\n        transport connections that this conceptual row\n\n        defines.  The value of activePersistent, activeOnDemand\n        and passive means this DLSw will accept any transport\n        connections, initiated by partner DLSw nodes, which\n        are defined by this conceptual row.  The value of\n        activePersistent means this DLSw will also initiate\n        the transport connections of this conceptual row and\n        retry periodically if necessary.  The value of\n        activeOnDemand means this DLSw will initiate a\n        transport connection of this conceptual row, if\n        there is a directory cache hits.  The value of\n        other is implementation specific.  The value of exclude\n        means that the specified node is not allowed to be\n        a partner to this DLSw node.  To take a certain\n        conceptual row definition out of service, a value of\n        notInService for dlswTConnConfigRowStatus should be\n        used.')
dlswTConnConfigSapList = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16).clone(hexValue="AA000000000000000000000000000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigSapList.setDescription('The SAP list indicates which SAPs are advertised to\n        the transport connection defined by this conceptual\n        row.  Only SAPs with even numbers are represented,\n        in the form of the most significant bit of the first\n        octet representing the SAP 0, the next most significant\n        bit representing the SAP 2, to the least significant\n        bit of the last octet representing the SAP 254.  Data\n        link switching is allowed for those SAPs which have\n        one in its corresponding bit, not allowed otherwise.\n        The whole SAP list has to be changed together.  Changing\n        the SAP list affects only new circuit establishments\n        and has no effect on established circuits.\n\n        This list can be used to restrict specific partners\n        from knowing about all the SAPs used by DLSw on all its\n        interfaces (these are represented in dlswIfSapList for\n        each interface).  For instance, one may want to run NetBIOS\n        with some partners but not others.\n\n        If a node supports sending run-time capabilities exchange\n        messages, changes to this object should cause that action.\n        When to start the run-time capabilities exchange is\n        implementation-specific.\n\n\n        The DEFVAL below indicates support for SAPs 0, 4, 8, and C.')
dlswTConnConfigAdvertiseMacNB = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 10), TruthValue().clone('true')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigAdvertiseMacNB.setDescription('The value of true indicates that any defined local MAC\n         addresses and NetBIOS names will be advertised to a\n         partner node via initial and (if supported) run-time\n         capabilities exchange messages.  The DLSw node should send\n         the appropriate exclusivity control vector to accompany\n         each list it sends, or to represent that the node is\n         explicitly configured to have a null list.\n\n         The value of false indicates that the DLSw node should not\n         send a MAC address list or NetBIOS name list, and should\n         also not send their corresponding exclusivity control\n         vectors.')
dlswTConnConfigInitCirRecvWndw = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(1)).setUnits('SSP messages').setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigInitCirRecvWndw.setDescription('The initial circuit receive pacing window size, in the unit\n        of SSP messages, to be used for future transport connections\n        activated using this table row.  The managed node sends this\n        value as its initial receive pacing window in its initial\n        capabilities exchange message.  Changing this value does not\n        affect the initial circuit receive pacing window size of\n        currently active transport connections.  If the standard window\n        pacing scheme is not supported, the value is zero.\n\n        A larger receive window value may be appropriate for partners\n        that are reachable only via physical paths that have longer\n        network delays.')
dlswTConnConfigOpens = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnConfigOpens.setDescription('Number of times transport connections entered\n        connected state according to the definition of\n        this conceptual row.')
dlswTConnConfigRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 2, 1, 13), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnConfigRowStatus.setDescription('This object is used by the manager to create\n        or delete the row entry in the dlswTConnConfigTable\n        following the RowStatus textual convention.  The value\n        of notInService will be used to take a conceptual\n        row definition out of use.')
dlswTConnOperTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 2, 3), )
if mibBuilder.loadTexts: dlswTConnOperTable.setDescription('A list of transport connections.   It is optional but\n        desirable for the agent to keep an entry for some\n        period of time after the transport connection is\n        disconnected.  This allows the manager to capture\n        additional useful information about the connection, in\n        particular, statistical information and the cause of the\n        disconnection.')
dlswTConnOperEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1), ).setIndexNames((0, "DLSW-MIB", "dlswTConnOperTDomain"), (0, "DLSW-MIB", "dlswTConnOperRemoteTAddr"))
if mibBuilder.loadTexts: dlswTConnOperEntry.setDescription('')
dlswTConnOperTDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 1), ObjectIdentifier())
if mibBuilder.loadTexts: dlswTConnOperTDomain.setDescription('The object identifier indicates the transport domain\n        of this transport connection.')
dlswTConnOperLocalTAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 2), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperLocalTAddr.setDescription('The local transport address for this transport connection.\n        This value could be different from dlswTConnConfigLocalAddr,\n        if the value of the latter were changed after this transport\n        connection was established.')
dlswTConnOperRemoteTAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 3), TAddress())
if mibBuilder.loadTexts: dlswTConnOperRemoteTAddr.setDescription('The remote transport address of this transport connection.')
dlswTConnOperEntryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 4), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperEntryTime.setDescription('The amount of time (in hundredths of a second) since this\n        transport connection conceptual row was created.')
dlswTConnOperConnectTime = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 5), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperConnectTime.setDescription("The amount of time (in hundredths of a second) since this\n        transport connection last entered the 'connected' state.\n        A value of zero means this transport connection has never\n        been established.")
dlswTConnOperState = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("connecting", 1), ("initCapExchange", 2), ("connected", 3), ("quiescing", 4), ("disconnecting", 5), ("disconnected", 6),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswTConnOperState.setDescription("The state of this transport connection.  The transport\n        connection enters `connecting' state when DLSw makes\n        a connection request to the transport layer.  Once initial\n        Capabilities Exchange is sent, the transport connection\n        enters enters `initCapExchange' state.  When partner\n        capabilities have been determined and the transport\n        connection is ready for sending CanUReach (CUR) messages,\n        it moves to the `connected' state.  When DLSw is in the\n        process of bringing down the connection, it is in the\n        `disconnecting' state.  When the transport layer\n        indicates one of its connections is disconnected, the\n        transport connection moves to the `disconnected' state.\n\n        Whereas all of the values will be returned in response\n        to a management protocol retrieval operation, only two\n        values may be specified in a management protocol set\n        operation: `quiescing' and `disconnecting'.  Changing\n        the value to `quiescing' prevents new circuits from being\n        established, and will cause a transport disconnect when\n        the last circuit on the connection goes away.  Changing\n        the value to `disconnecting' will force off all circuits\n        immediately and bring the connection to `disconnected'\n        state.")
dlswTConnOperConfigIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperConfigIndex.setDescription('The value of dlswTConnConfigIndex of the dlswTConnConfigEntry\n        that governs the configuration information used by this\n        dlswTConnOperEntry.  The manager can therefore normally\n        examine both configured and operational information\n        for this transport connection.\n\n        This value is zero if the corresponding dlswTConnConfigEntry\n        was deleted after the creation of this dlswTConnOperEntry.\n        If some fields in the former were changed but the conceptual\n        row was not deleted, some configuration information may not\n        be valid for this operational transport connection.  The\n        manager can compare dlswTConnOperConnectTime and\n        dlswTConnConfigLastModifyTime to determine if this condition\n        exists.')
dlswTConnOperFlowCntlMode = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("undetermined", 1), ("pacing", 2), ("other", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperFlowCntlMode.setDescription('The flow control mechanism in use on this transport connection.\n        This value is undetermined (1) before the mode of flow control\n        can be established on a new transport connection (i.e., after\n        CapEx is sent but before Capex or other SSP control messages\n        have been received).  Pacing (2) indicates that the standard\n        RFC 1795 pacing mechanism is in use.  Other (3) may be either\n        the RFC 1434+ xBusy mechanism operating to a back-level DLSw,\n        or a vendor-specific flow control method.  Whether it is xBusy\n        or not can be inferred from dlswTConnOperPartnerVersion.')
dlswTConnOperPartnerVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 9), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(2,2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerVersion.setDescription("This value identifies which version (first octet) and release\n        (second octet) of the DLSw standard is supported by this\n        partner DLSw. This information is obtained from a DLSw\n        capabilities exchange message received from the partner DLSw.\n        A string of zero length is returned before a Capabilities\n        Exchange message is received, or if one is never received.\n        A conceptual row with a dlswTConnOperState of `connected' but\n        a zero length partner version indicates that the partner is\n        a non-standard DLSw partner.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerVendorID = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 10), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(3,3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerVendorID.setDescription("This value identifies the IEEE-assigned organizationally\n        Unique Identifier (OUI) of the maker of this partner\n        DLSw.  This information is obtained from a DLSw\n        capabilities exchange message received from the partner DLSw.\n        A string of zero length is returned before a Capabilities\n        Exchange message is received, or if one is never received.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerVersionStr = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 11), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,253))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerVersionStr.setDescription("This value identifies the particular product version (e.g.,\n        product name, code level, fix level) of this partner DLSw.\n        The format of the actual version string is vendor-specific.\n        This information is obtained from a DLSw capabilities exchange\n        message received from the partner DLSw.\n        A string of zero length is returned before a Capabilities\n        Exchange message is received, if one is never received, or\n        if one is received but it does not contain a version string.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerInitPacingWndw = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerInitPacingWndw.setDescription("The value of the partner initial receive pacing window.  This\n        is our initial send pacing window for all new circuits on this\n        transport connection, as modified and granted by the first flow\n        control indication the partner sends on each circuit.\n        This information is obtained from a DLSw capabilities exchange\n        message received from the partner DLSw.\n        A value of zero is returned before a Capabilities\n        Exchange message is received, or if one is never received.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerSapList = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 13), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(16,16),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerSapList.setDescription("The Supported SAP List received in the capabilities\n        exchange message from the partner DLSw.  This list has\n        the same format described for dlswTConnConfigSapList.\n        A string of zero length is returned before a Capabilities\n        Exchange message is received, or if one is never received.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerNBExcl = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 14), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerNBExcl.setDescription("The value of true signifies that the NetBIOS names received\n        from this partner in the NetBIOS name list in its capabilities\n        exchange message are the only NetBIOS names reachable by\n        that partner.  `False' indicates that other NetBIOS names may\n        be reachable.  `False' should be returned before a Capabilities\n        Exchange message is received, if one is never received, or if\n        one is received without a NB Name Exclusivity CV.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerMacExcl = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 15), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerMacExcl.setDescription("The value of true signifies that the MAC addresses received\n        from this partner in the MAC address list in its capabilities\n        exchange message are the only MAC addresses reachable by\n        that partner.  `False' indicates that other MAC addresses may\n        be reachable.  `False' should be returned before a Capabilities\n        Exchange message is received, if one is never received, or if\n        one is received without a MAC Address Exclusivity CV.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerNBInfo = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("partial", 2), ("complete", 3), ("notApplicable", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerNBInfo.setDescription("It is up to this DSLw whether to keep either none, some,\n        or all of the NetBIOS name list that was received in\n        the capabilities exchange message sent by this partner DLSw.\n        This object identifies how much information was kept by\n        this DLSw.  These names are stored as userConfigured\n        remote entries in dlswDirNBTable.\n        A value of (4), notApplicable, should be returned before\n        a Capabilities Exchange message is received, or if one is\n        never received.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperPartnerMacInfo = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 17), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("partial", 2), ("complete", 3), ("notApplicable", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperPartnerMacInfo.setDescription("It is up to this DLSw whether to keep either none, some,\n        or all of the MAC address list that was received in the\n        capabilities exchange message sent by this partner DLSw.\n        This object identifies how much information was kept by\n        this DLSw.  These names are stored as userConfigured\n        remote entries in dlswDirMACTable.\n        A value of (4), notApplicable, should be returned before\n        a Capabilities Exchange message is received, or if one is\n        never received.\n\n        If an implementation chooses to keep dlswTConnOperEntrys in\n        the `disconnected' state, this value should remain unchanged.")
dlswTConnOperDiscTime = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 18), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperDiscTime.setDescription("The amount of time (in hundredths of a second) since the\n        dlswTConnOperState last entered `disconnected' state.")
dlswTConnOperDiscReason = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 19), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("other", 1), ("capExFailed", 2), ("transportLayerDisc", 3), ("operatorCommand", 4), ("lastCircuitDiscd", 5), ("protocolError", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperDiscReason.setDescription('This object signifies the reason that either prevented the\n        transport connection from entering the connected state, or\n        caused the transport connection to enter the disconnected\n        state.')
dlswTConnOperDiscActiveCir = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 20), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperDiscActiveCir.setDescription('The number of circuits active (not in DISCONNECTED state)\n        at the time the transport connection was last disconnected.\n        This value is zero if the transport connection has never\n        been connected.')
dlswTConnOperInDataPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 21), Counter32()).setUnits('SSP messages').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperInDataPkts.setDescription('The number of Switch-to-Switch Protocol (SSP) messages of\n        type DGRMFRAME, DATAFRAME, or INFOFRAME received on this\n        transport connection.')
dlswTConnOperOutDataPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 22), Counter32()).setUnits('SSP messages').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperOutDataPkts.setDescription('The number of Switch-to-Switch Protocol (SSP) messages of\n        type DGRMFRAME, DATAFRAME, or INFOFRAME transmitted on this\n        transport connection.')
dlswTConnOperInDataOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 23), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperInDataOctets.setDescription('The number octets in Switch-to-Switch Protocol (SSP) messages\n        of type DGRMFRAME, DATAFRAME, or INFOFRAME received on this\n        transport connection.  Each message is counted starting with\n        the first octet following the SSP message header.')
dlswTConnOperOutDataOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 24), Counter32()).setUnits('octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperOutDataOctets.setDescription('The number octets in Switch-to-Switch Protocol (SSP) messages\n        of type DGRMFRAME, DATAFRAME, or INFOFRAME transmitted on this\n        transport connection.  Each message is counted starting with\n        the first octet following the SSP message header.')
dlswTConnOperInCntlPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 25), Counter32()).setUnits('SSP messages').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperInCntlPkts.setDescription('The number of Switch-to-Switch Protocol (SSP) messages\n        received on this transport connection which were not of\n        type DGRMFRAME, DATAFRAME, or INFOFRAME.')
dlswTConnOperOutCntlPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 26), Counter32()).setUnits('SSP messages').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperOutCntlPkts.setDescription('The number of Switch-to-Switch Protocol (SSP) messages of\n        transmitted on this transport connection which were not of\n        type DGRMFRAME, DATAFRAME, or INFOFRAME.')
dlswTConnOperCURexSents = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperCURexSents.setDescription('The number of CanUReach_ex messages sent on this transport\n        connection.')
dlswTConnOperICRexRcvds = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 28), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperICRexRcvds.setDescription('The number of ICanReach_ex messages received on this transport\n        connection.')
dlswTConnOperCURexRcvds = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 29), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperCURexRcvds.setDescription('The number of CanUReach_ex messages received on this transport\n        connection.')
dlswTConnOperICRexSents = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperICRexSents.setDescription('The number of ICanReach_ex messages sent on this transport\n        connection.')
dlswTConnOperNQexSents = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 31), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperNQexSents.setDescription('The number of NetBIOS_NQ_ex (NetBIOS Name Query-explorer)\n\n        messages sent on this transport connection.')
dlswTConnOperNRexRcvds = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 32), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperNRexRcvds.setDescription('The number of NETBIOS_NR_ex (NetBIOS Name Recognized-explorer)\n        messages received on this transport connection.')
dlswTConnOperNQexRcvds = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 33), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperNQexRcvds.setDescription('The number of NETBIOS_NQ_ex messages received on this\n        transport connection.')
dlswTConnOperNRexSents = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 34), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperNRexSents.setDescription('The number of NETBIOS_NR_ex messages sent on this transport\n        connection.')
dlswTConnOperCirCreates = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 35), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperCirCreates.setDescription("The number of times that circuits entered `circuit_established'\n        state (not counting transitions from `circuit_restart').")
dlswTConnOperCircuits = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 3, 1, 36), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnOperCircuits.setDescription("The number of currently active circuits on this transport\n\n        connection, where `active' means not in `disconnected' state.")
dlswTConnSpecific = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 2, 4))
dlswTConnTcp = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1))
dlswTConnTcpConfigTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 1), )
if mibBuilder.loadTexts: dlswTConnTcpConfigTable.setDescription('This table defines the TCP transport connections that\n        will be either initiated by or accepted by this DSLw.\n        It augments the entries in dlswTConnConfigTable whose domain\n        is dlswTCPDomain.')
dlswTConnTcpConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 1, 1), ).setIndexNames((0, "DLSW-MIB", "dlswTConnConfigIndex"))
if mibBuilder.loadTexts: dlswTConnTcpConfigEntry.setDescription('Each conceptual row defines parameters that are\n        specific to dlswTCPDomain transport connections.')
dlswTConnTcpConfigKeepAliveInt = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,1800))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnTcpConfigKeepAliveInt.setDescription('The time in seconds between TCP keepAlive messages when\n        no traffic is flowing.  Zero signifies no keepAlive protocol.\n\n        Changes take effect only for new TCP connections.')
dlswTConnTcpConfigTcpConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,16)).clone(2)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnTcpConfigTcpConnections.setDescription('This is our preferred number of TCP connections within a\n        TCP transport connection.  The actual number used is negotiated\n        at capabilities exchange time. Changes take effect only\n        for new transport connections.')
dlswTConnTcpConfigMaxSegmentSize = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(4096)).setUnits('packets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswTConnTcpConfigMaxSegmentSize.setDescription('This is the number of bytes that this node is\n        willing to receive over the read TCP connection(s).\n        Changes take effect for new transport connections.')
dlswTConnTcpOperTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 2), )
if mibBuilder.loadTexts: dlswTConnTcpOperTable.setDescription('A list of TCP transport connections.   It is optional\n        but desirable for the agent to keep an entry for some\n        period of time after the transport connection is\n        disconnected.  This allows the manager to capture\n        additional useful information about the connection, in\n        particular, statistical information and the cause of the\n        disconnection.')
dlswTConnTcpOperEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 2, 1), ).setIndexNames((0, "DLSW-MIB", "dlswTConnOperTDomain"), (0, "DLSW-MIB", "dlswTConnOperRemoteTAddr"))
if mibBuilder.loadTexts: dlswTConnTcpOperEntry.setDescription('')
dlswTConnTcpOperKeepAliveInt = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,1800))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnTcpOperKeepAliveInt.setDescription('The time in seconds between TCP keepAlive messages when\n        no traffic is flowing.  Zero signifies no keepAlive protocol is\n        operating.')
dlswTConnTcpOperPrefTcpConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,16))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnTcpOperPrefTcpConnections.setDescription('This is the number of TCP connections preferred by this DLSw\n        partner, as received in its capabilities exchange message.')
dlswTConnTcpOperTcpConnections = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 2, 4, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,16))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswTConnTcpOperTcpConnections.setDescription('This is the actual current number of TCP connections within\n        this transport connection.')
dlswIfTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 3, 1), )
if mibBuilder.loadTexts: dlswIfTable.setDescription('The list of interfaces on which DLSw is active.')
dlswIfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 3, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: dlswIfEntry.setDescription('')
dlswIfRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 3, 1, 1, 1), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswIfRowStatus.setDescription('This object is used by the manager to create\n        or delete the row entry in the dlswIfTable\n        following the RowStatus textual convention.')
dlswIfVirtualSegment = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 3, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,4095),ValueRangeConstraint(65535,65535),)).clone(65535)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswIfVirtualSegment.setDescription('The segment number that uniquely identifies the virtual\n        segment to which this DLSw interface is connected.\n        Current source routing protocols limit this value to\n        the range 0 - 4095. (The value 0 is used by some\n        management applications for special test cases.)\n        A value of 65535 signifies that no virtual segment\n        is assigned to this interface.  For instance,\n        in a non-source routing environment, segment number\n        assignment is not required.')
dlswIfSapList = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 3, 1, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16).clone(hexValue="AA000000000000000000000000000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswIfSapList.setDescription('The SAP list indicates which SAPs are allowed to be\n        data link switched through this interface.  This list\n        has the same format described for dlswTConnConfigSapList.\n\n        When changes to this object take effect is implementation-\n        specific.  Turning off a particular SAP can destroy\n        active circuits that are using that SAP.  An agent\n        implementation may reject such changes until there are no\n        active circuits if it so chooses.  In this case, it is up\n        to the manager to close the circuits first, using\n        dlswCircuitState.\n\n        The DEFVAL below indicates support for SAPs 0, 4, 8, and C.')
dlswDirStat = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 4, 1))
dlswDirMacEntries = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirMacEntries.setDescription('The current total number of entries in the dlswDirMacTable.')
dlswDirMacCacheHits = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirMacCacheHits.setDescription('The number of times a cache search for a particular MAC address\n        resulted in success.')
dlswDirMacCacheMisses = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirMacCacheMisses.setDescription('The number of times a cache search for a particular MAC address\n        resulted in failure.')
dlswDirMacCacheNextIndex = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirMacCacheNextIndex.setDescription('The next value of dlswDirMacIndex to be assigned by\n        the agent.  A retrieval of this object atomically reserves\n        the returned value for use by the manager to create a row\n        in dlswDirMacTable.  This makes it possible for the agent\n        to control the index space of the MAC address cache, yet\n        allows the manager to administratively create new rows.')
dlswDirNBEntries = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirNBEntries.setDescription('The current total number of entries in the dlswDirNBTable.')
dlswDirNBCacheHits = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirNBCacheHits.setDescription('The number of times a cache search for a particular NetBIOS\n        name resulted in success.')
dlswDirNBCacheMisses = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirNBCacheMisses.setDescription('The number of times a cache search for a particular NetBIOS\n        name resulted in failure.')
dlswDirNBCacheNextIndex = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 4, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirNBCacheNextIndex.setDescription('The next value of dlswDirNBIndex to be assigned by the\n        agent.  A retrieval of this object atomically reserves\n        the returned value for use by the manager to create\n        a row in dlswDirNBTable.  This makes it possible for the\n        agent to control the index space for the NetBIOS name\n        cache, yet allows the manager to administratively\n        create new rows.')
dlswDirCache = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 4, 2))
dlswDirMacTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1), )
if mibBuilder.loadTexts: dlswDirMacTable.setDescription('This table contains locations of MAC addresses.\n        They could be either verified or not verified,\n\n        local or remote, and configured locally or learned\n        from either Capabilities Exchange messages or\n        directory searches.')
dlswDirMacEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1), ).setIndexNames((0, "DLSW-MIB", "dlswDirMacIndex"))
if mibBuilder.loadTexts: dlswDirMacEntry.setDescription('Indexed by dlswDirMacIndex.')
dlswDirMacIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)))
if mibBuilder.loadTexts: dlswDirMacIndex.setDescription('Uniquely identifies a conceptual row of this table.')
dlswDirMacMac = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 2), MacAddressNC()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacMac.setDescription('The MAC address, together with the dlswDirMacMask,\n        specifies a set of MAC addresses that are defined or\n        discovered through an interface or partner DLSw nodes.')
dlswDirMacMask = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 3), MacAddressNC().clone(hexValue="FFFFFFFFFFFF")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacMask.setDescription('The MAC address mask, together with the dlswDirMacMac,\n        specifies a set of MAC addresses that are defined or\n        discovered through an interface or partner DLSw nodes.')
dlswDirMacEntryType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("userConfiguredPublic", 2), ("userConfiguredPrivate", 3), ("partnerCapExMsg", 4), ("dynamic", 5),)).clone('userConfiguredPublic')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacEntryType.setDescription('The cause of the creation of this conceptual row.\n        It could be one of the three methods: (1) user\n        configured, including via management protocol\n        set operations, configuration file, command line\n        or equivalent methods; (2) learned from the\n        partner DLSw Capabilities Exchange messages;\n        and (3) dynamic, e.g., learned from ICanReach\n        messages, or LAN explorer frames.  Since only\n        individual MAC addresses can be dynamically learned,\n        dynamic entries will all have a mask of all FFs.\n\n        The public versus private distinction for user-\n        configured resources applies only to local resources\n        (UC remote resources are private), and indicates\n        whether that resource should be advertised in\n        capabilities exchange messages sent by this node.')
dlswDirMacLocationType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("local", 2), ("remote", 3),)).clone('local')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacLocationType.setDescription('The location of the resource (or a collection of\n        resources using a mask) of this conceptual row\n\n        is either (1) local - the resource is reachable\n        via an interface, or (2) remote - the resource\n        is reachable via a partner DLSw node (or a set\n        of partner DLSw nodes).')
dlswDirMacLocation = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 6), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacLocation.setDescription('Points to either the ifEntry, dlswTConnConfigEntry,\n        dlswTConnOperEntry, 0.0, or something that is implementation\n        specific.  It identifies the location of the MAC address\n        (or the collection of MAC addresses.)')
dlswDirMacStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("reachable", 2), ("notReachable", 3),)).clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacStatus.setDescription("This object specifies whether DLSw currently believes\n        the MAC address to be accessible at the specified location.\n        The value `notReachable' allows a configured resource\n        definition to be taken out of service when a search to\n        that resource fails (avoiding a repeat of the search).")
dlswDirMacLFSize = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 8), LFSize().clone('lfs65535')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacLFSize.setDescription('The largest size of the MAC INFO field (LLC header and data)\n        that a circuit to the MAC address can carry through this path.')
dlswDirMacRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 1, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirMacRowStatus.setDescription('This object is used by the manager to create\n        or delete the row entry in the dlswDirMacTable\n        following the RowStatus textual convention.')
dlswDirNBTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2), )
if mibBuilder.loadTexts: dlswDirNBTable.setDescription('This table contains locations of NetBIOS names.\n        They could be either verified or not verified,\n        local or remote, and configured locally or learned\n        from either Capabilities Exchange messages or\n        directory searches.')
dlswDirNBEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1), ).setIndexNames((0, "DLSW-MIB", "dlswDirNBIndex"))
if mibBuilder.loadTexts: dlswDirNBEntry.setDescription('Indexed by dlswDirNBIndex.')
dlswDirNBIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)))
if mibBuilder.loadTexts: dlswDirNBIndex.setDescription('Uniquely identifies a conceptual row of this table.')
dlswDirNBName = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 2), NBName()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBName.setDescription("The NetBIOS name (including `any char' and `wildcard'\n        characters) specifies a set of NetBIOS names that are\n        defined or discovered through an interface or partner\n        DLSw nodes.")
dlswDirNBNameType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("individual", 2), ("group", 3),)).clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBNameType.setDescription('Whether dlswDirNBName represents an (or a set of) individual\n        or group NetBIOS name(s).')
dlswDirNBEntryType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("userConfiguredPublic", 2), ("userConfiguredPrivate", 3), ("partnerCapExMsg", 4), ("dynamic", 5),)).clone('userConfiguredPublic')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBEntryType.setDescription('The cause of the creation of this conceptual row.\n        It could be one of the three methods: (1) user\n        configured, including via management protocol\n        set operations, configuration file, command line,\n        or equivalent methods; (2) learned from the\n        partner DLSw Capabilities Exchange messages;\n        and (3) dynamic, e.g., learned from ICanReach\n        messages, or test frames.  Since only actual\n        NetBIOS names can be dynamically learned, dynamic\n        entries will not contain any char or wildcard\n        characters.\n\n        The public versus private distinction for user-\n        configured resources applies only to local resources\n        (UC remote resources are private), and indicates\n        whether that resource should be advertised in\n        capabilities exchange messages sent by this node.')
dlswDirNBLocationType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("local", 2), ("remote", 3),)).clone('local')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBLocationType.setDescription('The location of the resource (or a collection of resources\n        using any char/wildcard characters) of this conceptual row\n        is either (1) local - the resource is reachable via an\n        interface, or (2) remote - the resource is reachable via a\n        a partner DLSw node (or a set of partner DLSw nodes).')
dlswDirNBLocation = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 6), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBLocation.setDescription('Points to either the ifEntry, dlswTConnConfigEntry,\n        dlswTConnOperEntry, 0.0, or something that is implementation\n        specific.  It identifies the location of the NetBIOS name\n        or the set of NetBIOS names.')
dlswDirNBStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("reachable", 2), ("notReachable", 3),)).clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBStatus.setDescription("This object specifies whether DLSw currently believes\n        the NetBIOS name to be accessible at the specified location.\n        The value `notReachable' allows a configured resource\n        definition to be taken out of service when a search to\n        that resource fails (avoiding a repeat of the search).")
dlswDirNBLFSize = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 8), LFSize().clone('lfs65535')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBLFSize.setDescription('The largest size of the MAC INFO field (LLC header and data)\n        that a circuit to the NB name can carry through this path.')
dlswDirNBRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 2, 2, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswDirNBRowStatus.setDescription('This object is used by manager to create\n        or delete the row entry in the dlswDirNBTable\n        following the RowStatus textual convention.')
dlswDirLocate = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 4, 3))
dlswDirLocateMacTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 1), )
if mibBuilder.loadTexts: dlswDirLocateMacTable.setDescription('This table is used to retrieve all entries in the\n        dlswDirMacTable that match a given MAC address,\n        in the order of the best matched first, the\n        second best matched second, and so on, till\n        no more entries match the given MAC address.')
dlswDirLocateMacEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 1, 1), ).setIndexNames((0, "DLSW-MIB", "dlswDirLocateMacMac"), (0, "DLSW-MIB", "dlswDirLocateMacMatch"))
if mibBuilder.loadTexts: dlswDirLocateMacEntry.setDescription('Indexed by dlswDirLocateMacMac and dlswDirLocateMacMatch.\n        The first object is the MAC address of interest, and\n        the second object is the order in the list of all\n        entries that match the MAC address.')
dlswDirLocateMacMac = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 1, 1, 1), MacAddressNC())
if mibBuilder.loadTexts: dlswDirLocateMacMac.setDescription('The MAC address to be located.')
dlswDirLocateMacMatch = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255)))
if mibBuilder.loadTexts: dlswDirLocateMacMatch.setDescription('The order of the entries of dlswDirMacTable\n        that match dlswDirLocateMacMac.  A value of\n        one represents the entry that best matches the\n        MAC address.  A value of two represents the second\n        best matched entry, and so on.')
dlswDirLocateMacLocation = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 1, 1, 3), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirLocateMacLocation.setDescription('Points to the dlswDirMacEntry.')
dlswDirLocateNBTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 2), )
if mibBuilder.loadTexts: dlswDirLocateNBTable.setDescription('This table is used to retrieve all entries in the\n        dlswDirNBTable that match a given NetBIOS name,\n        in the order of the best matched first, the\n        second best matched second, and so on, till\n        no more entries match the given NetBIOS name.')
dlswDirLocateNBEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 2, 1), ).setIndexNames((0, "DLSW-MIB", "dlswDirLocateNBName"), (0, "DLSW-MIB", "dlswDirLocateNBMatch"))
if mibBuilder.loadTexts: dlswDirLocateNBEntry.setDescription('Indexed by dlswDirLocateNBName and dlswDirLocateNBMatch.\n        The first object is the NetBIOS name of interest, and\n        the second object is the order in the list of all\n        entries that match the NetBIOS name.')
dlswDirLocateNBName = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 2, 1, 1), NBName())
if mibBuilder.loadTexts: dlswDirLocateNBName.setDescription('The NetBIOS name to be located (no any char or wildcards).')
dlswDirLocateNBMatch = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255)))
if mibBuilder.loadTexts: dlswDirLocateNBMatch.setDescription('The order of the entries of dlswDirNBTable\n        that match dlswDirLocateNBName.  A value of\n        one represents the entry that best matches the\n        NetBIOS name.  A value of two represents the second\n        best matched entry, and so on.')
dlswDirLocateNBLocation = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 4, 3, 2, 1, 3), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswDirLocateNBLocation.setDescription('Points to the dlswDirNBEntry.')
dlswCircuitStat = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 5, 1))
dlswCircuitStatActives = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 5, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitStatActives.setDescription('The current number of circuits in dlswCircuitTable that are\n        not in the disconnected state.')
dlswCircuitStatCreates = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 5, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitStatCreates.setDescription("The total number of entries ever added to dlswCircuitTable,\n        or reactivated upon exiting `disconnected' state.")
dlswCircuitTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 5, 2), )
if mibBuilder.loadTexts: dlswCircuitTable.setDescription('This table is the circuit representation in the DLSw\n        entity. Virtual data links are used to represent any internal\n        end stations.  There is a conceptual row associated with\n        each data link.  Thus, for circuits without an intervening\n        transport connection, there are two conceptual rows\n        for each circuit.\n\n        The table consists of the circuits being established,\n        established, and as an implementation option, circuits that\n        have been disconnected.  For circuits carried over\n        transport connections, an entry is created after\n        the CUR_cs was sent or received.  For circuits between\n        two locally attached devices, or internal virtual MAC\n        addresses, an entry is created when the equivalent of\n        CUR_cs sent/received status is reached.\n\n        End station 1 (S1) and End station 2 (S2) are used to\n        represent the two end stations of the circuit.\n        S1 is always an end station which is locally attached.\n        S2 may be locally attached or remote.  If it is locally\n        attached, the circuit will be represented by two rows indexed\n        by (A, B) and (B, A) where A & B are the relevant MACs/SAPs.\n\n        The table may be used to store the causes of disconnection of\n        circuits.  It is recommended that the oldest disconnected\n        circuit entry be removed from this table when the memory\n        space of disconnected circuits is needed.')
dlswCircuitEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1), ).setIndexNames((0, "DLSW-MIB", "dlswCircuitS1Mac"), (0, "DLSW-MIB", "dlswCircuitS1Sap"), (0, "DLSW-MIB", "dlswCircuitS2Mac"), (0, "DLSW-MIB", "dlswCircuitS2Sap"))
if mibBuilder.loadTexts: dlswCircuitEntry.setDescription('')
dlswCircuitS1Mac = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 1), MacAddressNC())
if mibBuilder.loadTexts: dlswCircuitS1Mac.setDescription('The MAC Address of End Station 1 (S1) used for this circuit.')
dlswCircuitS1Sap = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1))
if mibBuilder.loadTexts: dlswCircuitS1Sap.setDescription('The SAP at End Station 1 (S1) used for this circuit.')
dlswCircuitS1IfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS1IfIndex.setDescription('The ifEntry index of the local interface through which S1\n        can be reached.')
dlswCircuitS1DlcType = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 4), DlcType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS1DlcType.setDescription('The DLC protocol in use between the DLSw node and S1.')
dlswCircuitS1RouteInfo = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,30))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS1RouteInfo.setDescription('If source-route bridging is in use between the DLSw\n        node and S1, this is the routing information field\n        describing the path between the two devices.\n        Otherwise the value will be an OCTET STRING of\n        zero length.')
dlswCircuitS1CircuitId = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 6), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(8,8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS1CircuitId.setDescription('The Circuit ID assigned by this DLSw node to this circuit.\n        The first four octets are the DLC port Id, and\n        the second four octets are the Data Link Correlator.\n        If the DLSw SSP was not used to establish this circuit,\n        the value will be a string of zero length.')
dlswCircuitS1Dlc = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 7), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS1Dlc.setDescription('Points to a conceptual row of the underlying DLC MIB,\n        which could either be the standard MIBs (e.g., the SDLC),\n        or an enterprise-specific DLC MIB.')
dlswCircuitS2Mac = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 8), MacAddressNC())
if mibBuilder.loadTexts: dlswCircuitS2Mac.setDescription('The MAC Address of End Station 2 (S2) used for this circuit.')
dlswCircuitS2Sap = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1))
if mibBuilder.loadTexts: dlswCircuitS2Sap.setDescription('The SAP at End Station 2 (S2) used for this circuit.')
dlswCircuitS2Location = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 10), EndStationLocation()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS2Location.setDescription('The location of End Station 2 (S2).\n        If the location of End Station 2 is local, the\n        interface information will be available in the\n        conceptual row whose S1 and S2 are the S2 and\n        the S1 of this conceptual row, respectively.')
dlswCircuitS2TDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 11), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS2TDomain.setDescription('If the location of End Station 2 is remote,\n        this value is the transport domain of the\n        transport protocol the circuit is running\n        over.  Otherwise, the value is 0.0.')
dlswCircuitS2TAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 12), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS2TAddress.setDescription('If the location of End Station 2 is remote,\n        this object contains the address of the partner\n        DLSw, else it will be an OCTET STRING of zero length.')
dlswCircuitS2CircuitId = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 13), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(8,8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitS2CircuitId.setDescription('The Circuit ID assigned to this circuit by the partner\n        DLSw node.  The first four octets are the DLC port Id, and\n        the second four octets are the Data Link Correlator.\n        If the DLSw SSP was not used to establish this circuit,\n        the value will be a string of zero length.')
dlswCircuitOrigin = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("s1", 1), ("s2", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitOrigin.setDescription('This object specifies which of the two end stations\n        initiated the establishment of this circuit.')
dlswCircuitEntryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 15), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitEntryTime.setDescription('The amount of time (in hundredths of a second) since this\n        circuit table conceptual row was created.')
dlswCircuitStateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 16), TimeTicks()).setUnits('hundredths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitStateTime.setDescription('The amount of time (in hundredths of a second) since this\n        circuit entered the current state.')
dlswCircuitState = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 17), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13,))).clone(namedValues=NamedValues(("disconnected", 1), ("circuitStart", 2), ("resolvePending", 3), ("circuitPending", 4), ("circuitEstablished", 5), ("connectPending", 6), ("contactPending", 7), ("connected", 8), ("disconnectPending", 9), ("haltPending", 10), ("haltPendingNoack", 11), ("circuitRestart", 12), ("restartPending", 13),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswCircuitState.setDescription("The current state of this circuit.  The agent, implementation\n        specific, may choose to keep entries for some period of time\n        after circuit disconnect, so the manager can gather the time\n        and cause of disconnection.\n\n        While all of the specified values may be returned from a GET\n        operation, the only SETable value is `disconnectPending'.\n        When this value is set, DLSw should perform the appropriate\n        action given its previous state (e.g., send HALT_DL if the\n        state was `connected') to bring the circuit down to the\n        `disconnected' state.  Both the partner DLSw and local end\n        station(s) should be notified as appropriate.\n\n        This MIB provides no facility to re-establish a disconnected\n        circuit, because in DLSw this should be an end station-driven\n        function.")
dlswCircuitPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 18), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("unsupported", 1), ("low", 2), ("medium", 3), ("high", 4), ("highest", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitPriority.setDescription("The transmission priority of this circuit as understood by\n        this DLSw node.  This value is determined by the two DLSw\n        nodes at circuit startup time.  If this DLSw node does not\n        support DLSw circuit priority, the value `unsupported' should\n        be returned.")
dlswCircuitFCSendGrantedUnits = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 19), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCSendGrantedUnits.setDescription('The number of paced SSP messages that this DLSw is currently\n        authorized to send on this circuit before it must stop and\n        wait for an additional flow control indication from the\n        partner DLSw.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCSendCurrentWndw = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 20), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCSendCurrentWndw.setDescription("The current window size that this DLSw is using in its role\n        as a data sender.  This is the value by which this DLSw would\n        increase the number of messages it is authorized to send, if\n        it were to receive a flow control indication with the bits\n        specifying `repeat window'.\n\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.")
dlswCircuitFCRecvGrantedUnits = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 21), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCRecvGrantedUnits.setDescription('The current number of paced SSP messages that this DLSw has\n        authorized the partner DLSw to send on this circuit before\n        the partner DLSw must stop and wait for an additional flow\n        control indication from this DLSw.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCRecvCurrentWndw = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 22), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCRecvCurrentWndw.setDescription("The current window size that this DLSw is using in its role\n        as a data receiver.  This is the number of additional paced\n        SSP messages that this DLSw would be authorizing its DLSw\n        partner to send, if this DLSw were to send a flow control\n        indication with the bits specifying `repeat window'.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.")
dlswCircuitFCLargestRecvGranted = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 23), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCLargestRecvGranted.setDescription('The largest receive window size granted by this DLSw during\n        the current activation of this circuit.  This is not the\n        largest number of messages granted at any time, but the\n        largest window size as represented by FCIND operator bits.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCLargestSendGranted = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 24), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCLargestSendGranted.setDescription('The largest send (with respect to this DLSw) window size\n        granted by the partner DLSw during the current activation of\n        this circuit.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCHalveWndwSents = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCHalveWndwSents.setDescription('The number of Halve Window operations this DLSw has sent on\n        this circuit, in its role as a data receiver.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCResetOpSents = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCResetOpSents.setDescription('The number of Reset Window operations this DLSw has sent on\n        this circuit, in its role as a data receiver.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCHalveWndwRcvds = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCHalveWndwRcvds.setDescription('The number of Halve Window operations this DLSw has received on\n        this circuit, in its role as a data sender.\n\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitFCResetOpRcvds = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 28), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitFCResetOpRcvds.setDescription('The number of Reset Window operations this DLSw has received on\n        this circuit, in its role as a data sender.\n        The value zero should be returned if this circuit is not\n        running the DLSw pacing protocol.')
dlswCircuitDiscReasonLocal = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 29), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("endStationDiscRcvd", 1), ("endStationDlcError", 2), ("protocolError", 3), ("operatorCommand", 4), ("haltDlRcvd", 5), ("haltDlNoAckRcvd", 6), ("transportConnClosed", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitDiscReasonLocal.setDescription('The reason why this circuit was last disconnected, as seen\n        by this DLSw node.\n\n        This object is present only if the agent keeps circuit\n        table entries around for some period after circuit disconnect.')
dlswCircuitDiscReasonRemote = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 30), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("unknown", 1), ("endStationDiscRcvd", 2), ("endStationDlcError", 3), ("protocolError", 4), ("operatorCommand", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitDiscReasonRemote.setDescription("The generic reason code why this circuit was last\n        disconnected, as reported by the DLSw partner in a HALT_DL\n\n        or HALT_DL_NOACK.  If the partner does not send a reason\n        code in these messages, or the DLSw implementation does\n        not report receiving one, the value `unknown' is returned.\n\n        This object is present only if the agent keeps circuit table\n        entries around for some period after circuit disconnect.")
dlswCircuitDiscReasonRemoteData = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 5, 2, 1, 31), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(4,4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswCircuitDiscReasonRemoteData.setDescription('Implementation-specific data reported by the DLSw partner in\n        a HALT_DL or HALT_DL_NOACK, to help specify how and why this\n        circuit was last disconnected.  If the partner does not send\n        this data in these messages, or the DLSw implementation does\n        not report receiving it, a string of zero length is returned.\n\n        This object is present only if the agent keeps circuit table\n        entries around for some period after circuit disconnect.')
dlswSdlcLsEntries = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 6, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dlswSdlcLsEntries.setDescription('The number of entries in dlswSdlcLsTable.')
dlswSdlcLsTable = MibTable((1, 3, 6, 1, 2, 1, 46, 1, 6, 2), )
if mibBuilder.loadTexts: dlswSdlcLsTable.setDescription('The table defines the virtual MAC addresses for those\n        SDLC link stations that participate in data link switching.')
dlswSdlcLsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SNA-SDLC-MIB", "sdlcLSAddress"))
if mibBuilder.loadTexts: dlswSdlcLsEntry.setDescription('The index of this table is the ifIndex value for the\n        SDLC port which owns this link station and the poll\n        address of the particular SDLC link station.')
dlswSdlcLsLocalMac = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 1), MacAddressNC()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsLocalMac.setDescription('The virtual MAC address used to represent the SDLC-attached\n        link station to the rest of the DLSw network.')
dlswSdlcLsLocalSap = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsLocalSap.setDescription('The SAP used to represent this link station.')
dlswSdlcLsLocalIdBlock = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 3), DisplayString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(3,3),)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsLocalIdBlock.setDescription('The block number is the first three digits of the node_id,\n\n        if available.  These 3 hexadecimal digits identify the\n        product.')
dlswSdlcLsLocalIdNum = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 4), DisplayString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(5,5),)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsLocalIdNum.setDescription('The ID number is the last 5 digits of the node_id, if\n        available.  These 5 hexadecimal digits are\n        administratively defined and combined with the 3 digit\n        block number form the node_id.  This node_id is used to\n        identify the local node and is included in SNA XIDs.')
dlswSdlcLsRemoteMac = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 5), MacAddressNC().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsRemoteMac.setDescription('The MAC address to which DLSw should attempt to connect\n        this link station. If this information is not available,\n        a length of zero for this object should be returned.')
dlswSdlcLsRemoteSap = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 6), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(1,1),)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsRemoteSap.setDescription('The SAP of the remote station to which this link\n        station should be connected.  If this information\n        is not available, a length of zero for this object\n        should be returned.')
dlswSdlcLsRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 46, 1, 6, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dlswSdlcLsRowStatus.setDescription('This object is used by the manager to create\n        or delete the row entry in the dlswSdlcLsTable\n\n        following the RowStatus textual convention.')
dlswTrapControl = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 1, 10))
dlswTrapCntlTConnPartnerReject = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 10, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("partial", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswTrapCntlTConnPartnerReject.setDescription("Indicates whether the DLSw is permitted to emit partner\n        reject related traps.  With the value of `enabled'\n        the DLSw will emit all partner reject related traps.\n        With the value of `disabled' the DLSw will not emit\n        any partner reject related traps.  With the value\n        of `partial' the DLSw will only emits partner reject\n        traps for CapEx reject.  The changes take effect\n        immediately.")
dlswTrapCntlTConnProtViolation = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 10, 2), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswTrapCntlTConnProtViolation.setDescription('Indicates whether the DLSw is permitted to generate\n        protocol-violation traps on the events such as\n        window size violation.  The changes take effect\n        immediately.')
dlswTrapCntlTConn = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 10, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("partial", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswTrapCntlTConn.setDescription("Indicates whether the DLSw is permitted to emit transport\n        connection up and down traps.  With the value of `enabled'\n        the DLSw will emit traps when connections enter `connected'\n        and `disconnected' states.  With the value of `disabled'\n        the DLSw will not emit traps when connections enter of\n        `connected' and `disconnected' states.  With the value\n        of `partial' the DLSw will only emits transport connection\n        down traps when the connection is closed with busy.\n        The changes take effect immediately.")
dlswTrapCntlCircuit = MibScalar((1, 3, 6, 1, 2, 1, 46, 1, 1, 10, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("partial", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dlswTrapCntlCircuit.setDescription("Indicates whether the DLSw is permitted to generate\n        circuit up and down traps.  With the value of `enabled'\n        the DLSw will emit traps when circuits enter `connected'\n        and `disconnected' states.  With the value of `disabled'\n        the DLSw will not emit traps when circuits enter of\n        `connected' and `disconnected' states.  With the value\n        of `partial' the DLSw will emit traps only for those\n        circuits that are initiated by this DLSw, e.g.,\n        originating the CUR_CS message.  The changes take effect\n        immediately.")
dlswTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 1, 0))
dlswTrapTConnPartnerReject = NotificationType((1, 3, 6, 1, 2, 1, 46, 1, 0, 1)).setObjects(*(("DLSW-MIB", "dlswTConnOperTDomain"), ("DLSW-MIB", "dlswTConnOperRemoteTAddr"),))
if mibBuilder.loadTexts: dlswTrapTConnPartnerReject.setDescription('This trap is sent each time a transport connection\n        is rejected by a partner DLSw during Capabilities\n        Exchanges.  The emission of this trap is controlled\n        by dlswTrapCntlTConnPartnerReject.')
dlswTrapTConnProtViolation = NotificationType((1, 3, 6, 1, 2, 1, 46, 1, 0, 2)).setObjects(*(("DLSW-MIB", "dlswTConnOperTDomain"), ("DLSW-MIB", "dlswTConnOperRemoteTAddr"),))
if mibBuilder.loadTexts: dlswTrapTConnProtViolation.setDescription('This trap is sent each time a protocol violation is\n        detected for a transport connection.  The emission of this\n        trap is controlled by dlswTrapCntlTConnProtViolation.')
dlswTrapTConnUp = NotificationType((1, 3, 6, 1, 2, 1, 46, 1, 0, 3)).setObjects(*(("DLSW-MIB", "dlswTConnOperTDomain"), ("DLSW-MIB", "dlswTConnOperRemoteTAddr"),))
if mibBuilder.loadTexts: dlswTrapTConnUp.setDescription("This trap is sent each time a transport connection\n        enters `connected' state.  The emission of this trap\n        is controlled by dlswTrapCntlTConn.")
dlswTrapTConnDown = NotificationType((1, 3, 6, 1, 2, 1, 46, 1, 0, 4)).setObjects(*(("DLSW-MIB", "dlswTConnOperTDomain"), ("DLSW-MIB", "dlswTConnOperRemoteTAddr"),))
if mibBuilder.loadTexts: dlswTrapTConnDown.setDescription("This trap is sent each time a transport connection\n        enters `disconnected' state.  The emission of this trap\n        is controlled by dlswTrapCntlTConn.")
dlswTrapCircuitUp = NotificationType((1, 3, 6, 1, 2, 1, 46, 1, 0, 5)).setObjects(*(("DLSW-MIB", "dlswCircuitS1Mac"), ("DLSW-MIB", "dlswCircuitS1Sap"), ("DLSW-MIB", "dlswCircuitS2Mac"), ("DLSW-MIB", "dlswCircuitS2Sap"),))
if mibBuilder.loadTexts: dlswTrapCircuitUp.setDescription("This trap is sent each time a circuit enters `connected'\n        state.  The emission of this trap is controlled by\n        dlswTrapCntlCircuit.")
dlswTrapCircuitDown = NotificationType((1, 3, 6, 1, 2, 1, 46, 1, 0, 6)).setObjects(*(("DLSW-MIB", "dlswCircuitS1Mac"), ("DLSW-MIB", "dlswCircuitS1Sap"), ("DLSW-MIB", "dlswCircuitS2Mac"), ("DLSW-MIB", "dlswCircuitS2Sap"),))
if mibBuilder.loadTexts: dlswTrapCircuitDown.setDescription("This trap is sent each time a circuit enters `disconnected'\n        state.  The emission of this trap is controlled by\n        dlswTrapCntlCircuit.")
dlswConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 3))
dlswCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 3, 1))
dlswGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 46, 3, 2))
dlswCoreCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 46, 3, 1, 1)).setObjects(*(("DLSW-MIB", "dlswNodeGroup"), ("DLSW-MIB", "dlswTConnStatGroup"), ("DLSW-MIB", "dlswTConnConfigGroup"), ("DLSW-MIB", "dlswTConnOperGroup"), ("DLSW-MIB", "dlswInterfaceGroup"), ("DLSW-MIB", "dlswCircuitGroup"), ("DLSW-MIB", "dlswCircuitStatGroup"), ("DLSW-MIB", "dlswNotificationGroup"), ("DLSW-MIB", "dlswNodeNBGroup"), ("DLSW-MIB", "dlswTConnNBGroup"),))
if mibBuilder.loadTexts: dlswCoreCompliance.setDescription('The core compliance statement for all DLSw nodes.')
dlswTConnTcpCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 46, 3, 1, 2)).setObjects(*(("DLSW-MIB", "dlswTConnTcpConfigGroup"), ("DLSW-MIB", "dlswTConnTcpOperGroup"),))
if mibBuilder.loadTexts: dlswTConnTcpCompliance.setDescription('Compliance for DLSw nodes that use TCP as a\n        transport connection protocol.')
dlswDirCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 46, 3, 1, 3)).setObjects(*(("DLSW-MIB", "dlswDirGroup"), ("DLSW-MIB", "dlswDirNBGroup"),))
if mibBuilder.loadTexts: dlswDirCompliance.setDescription('Compliance for DLSw nodes that provide a directory\n        function.')
dlswDirLocateCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 46, 3, 1, 4)).setObjects(*(("DLSW-MIB", "dlswDirLocateGroup"), ("DLSW-MIB", "dlswDirLocateNBGroup"),))
if mibBuilder.loadTexts: dlswDirLocateCompliance.setDescription('Compliance for DLSw nodes that provide an ordered\n        list of directory entries for a given resource.')
dlswSdlcCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 46, 3, 1, 5)).setObjects(*(("DLSW-MIB", "dlswSdlcGroup"),))
if mibBuilder.loadTexts: dlswSdlcCompliance.setDescription('Compliance for DLSw nodes that support SDLC.')
dlswNodeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 1)).setObjects(*(("DLSW-MIB", "dlswNodeVersion"), ("DLSW-MIB", "dlswNodeVendorID"), ("DLSW-MIB", "dlswNodeVersionString"), ("DLSW-MIB", "dlswNodeStdPacingSupport"), ("DLSW-MIB", "dlswNodeStatus"), ("DLSW-MIB", "dlswNodeUpTime"), ("DLSW-MIB", "dlswNodeVirtualSegmentLFSize"), ("DLSW-MIB", "dlswNodeResourceMacExclusivity"), ("DLSW-MIB", "dlswTrapCntlTConnPartnerReject"), ("DLSW-MIB", "dlswTrapCntlTConnProtViolation"), ("DLSW-MIB", "dlswTrapCntlTConn"), ("DLSW-MIB", "dlswTrapCntlCircuit"),))
if mibBuilder.loadTexts: dlswNodeGroup.setDescription('Conformance group for DLSw node general information.')
dlswNodeNBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 2)).setObjects(*(("DLSW-MIB", "dlswNodeResourceNBExclusivity"),))
if mibBuilder.loadTexts: dlswNodeNBGroup.setDescription('Conformance group for DLSw node general information\n        specifically for nodes that support NetBIOS.')
dlswTConnStatGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 3)).setObjects(*(("DLSW-MIB", "dlswTConnStatActiveConnections"), ("DLSW-MIB", "dlswTConnStatCloseIdles"), ("DLSW-MIB", "dlswTConnStatCloseBusys"),))
if mibBuilder.loadTexts: dlswTConnStatGroup.setDescription('Conformance group for statistics for transport\n        connections.')
dlswTConnConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 4)).setObjects(*(("DLSW-MIB", "dlswTConnConfigTDomain"), ("DLSW-MIB", "dlswTConnConfigLocalTAddr"), ("DLSW-MIB", "dlswTConnConfigRemoteTAddr"), ("DLSW-MIB", "dlswTConnConfigLastModifyTime"), ("DLSW-MIB", "dlswTConnConfigEntryType"), ("DLSW-MIB", "dlswTConnConfigGroupDefinition"), ("DLSW-MIB", "dlswTConnConfigSetupType"), ("DLSW-MIB", "dlswTConnConfigSapList"), ("DLSW-MIB", "dlswTConnConfigAdvertiseMacNB"), ("DLSW-MIB", "dlswTConnConfigInitCirRecvWndw"), ("DLSW-MIB", "dlswTConnConfigOpens"), ("DLSW-MIB", "dlswTConnConfigRowStatus"),))
if mibBuilder.loadTexts: dlswTConnConfigGroup.setDescription('Conformance group for the configuration of\n        transport connections.')
dlswTConnOperGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 5)).setObjects(*(("DLSW-MIB", "dlswTConnOperLocalTAddr"), ("DLSW-MIB", "dlswTConnOperEntryTime"), ("DLSW-MIB", "dlswTConnOperConnectTime"), ("DLSW-MIB", "dlswTConnOperState"), ("DLSW-MIB", "dlswTConnOperConfigIndex"), ("DLSW-MIB", "dlswTConnOperFlowCntlMode"), ("DLSW-MIB", "dlswTConnOperPartnerVersion"), ("DLSW-MIB", "dlswTConnOperPartnerVendorID"), ("DLSW-MIB", "dlswTConnOperPartnerVersionStr"), ("DLSW-MIB", "dlswTConnOperPartnerInitPacingWndw"), ("DLSW-MIB", "dlswTConnOperPartnerSapList"), ("DLSW-MIB", "dlswTConnOperPartnerMacExcl"), ("DLSW-MIB", "dlswTConnOperPartnerMacInfo"), ("DLSW-MIB", "dlswTConnOperDiscTime"), ("DLSW-MIB", "dlswTConnOperDiscReason"), ("DLSW-MIB", "dlswTConnOperDiscActiveCir"), ("DLSW-MIB", "dlswTConnOperInDataPkts"), ("DLSW-MIB", "dlswTConnOperOutDataPkts"), ("DLSW-MIB", "dlswTConnOperInDataOctets"), ("DLSW-MIB", "dlswTConnOperOutDataOctets"), ("DLSW-MIB", "dlswTConnOperInCntlPkts"), ("DLSW-MIB", "dlswTConnOperOutCntlPkts"), ("DLSW-MIB", "dlswTConnOperCURexSents"), ("DLSW-MIB", "dlswTConnOperICRexRcvds"), ("DLSW-MIB", "dlswTConnOperCURexRcvds"), ("DLSW-MIB", "dlswTConnOperICRexSents"), ("DLSW-MIB", "dlswTConnOperCirCreates"), ("DLSW-MIB", "dlswTConnOperCircuits"),))
if mibBuilder.loadTexts: dlswTConnOperGroup.setDescription('Conformance group for operation information for\n        transport connections.')
dlswTConnNBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 6)).setObjects(*(("DLSW-MIB", "dlswTConnOperPartnerNBExcl"), ("DLSW-MIB", "dlswTConnOperPartnerNBInfo"), ("DLSW-MIB", "dlswTConnOperNQexSents"), ("DLSW-MIB", "dlswTConnOperNRexRcvds"), ("DLSW-MIB", "dlswTConnOperNQexRcvds"), ("DLSW-MIB", "dlswTConnOperNRexSents"),))
if mibBuilder.loadTexts: dlswTConnNBGroup.setDescription('Conformance group for operation information for\n        transport connections, specifically for nodes\n        that support NetBIOS.')
dlswTConnTcpConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 7)).setObjects(*(("DLSW-MIB", "dlswTConnTcpConfigKeepAliveInt"), ("DLSW-MIB", "dlswTConnTcpConfigTcpConnections"), ("DLSW-MIB", "dlswTConnTcpConfigMaxSegmentSize"),))
if mibBuilder.loadTexts: dlswTConnTcpConfigGroup.setDescription('Conformance group for configuration information for\n        transport connections using TCP.')
dlswTConnTcpOperGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 8)).setObjects(*(("DLSW-MIB", "dlswTConnTcpOperKeepAliveInt"), ("DLSW-MIB", "dlswTConnTcpOperPrefTcpConnections"), ("DLSW-MIB", "dlswTConnTcpOperTcpConnections"),))
if mibBuilder.loadTexts: dlswTConnTcpOperGroup.setDescription('Conformance group for operation information for\n        transport connections using TCP.')
dlswInterfaceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 9)).setObjects(*(("DLSW-MIB", "dlswIfRowStatus"), ("DLSW-MIB", "dlswIfVirtualSegment"), ("DLSW-MIB", "dlswIfSapList"),))
if mibBuilder.loadTexts: dlswInterfaceGroup.setDescription('Conformance group for DLSw interfaces.')
dlswDirGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 10)).setObjects(*(("DLSW-MIB", "dlswDirMacEntries"), ("DLSW-MIB", "dlswDirMacCacheHits"), ("DLSW-MIB", "dlswDirMacCacheMisses"), ("DLSW-MIB", "dlswDirMacCacheNextIndex"), ("DLSW-MIB", "dlswDirMacMac"), ("DLSW-MIB", "dlswDirMacMask"), ("DLSW-MIB", "dlswDirMacEntryType"), ("DLSW-MIB", "dlswDirMacLocationType"), ("DLSW-MIB", "dlswDirMacLocation"), ("DLSW-MIB", "dlswDirMacStatus"), ("DLSW-MIB", "dlswDirMacLFSize"), ("DLSW-MIB", "dlswDirMacRowStatus"),))
if mibBuilder.loadTexts: dlswDirGroup.setDescription('Conformance group for DLSw directory using MAC\n        addresses.')
dlswDirNBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 11)).setObjects(*(("DLSW-MIB", "dlswDirNBEntries"), ("DLSW-MIB", "dlswDirNBCacheHits"), ("DLSW-MIB", "dlswDirNBCacheMisses"), ("DLSW-MIB", "dlswDirNBCacheNextIndex"), ("DLSW-MIB", "dlswDirNBName"), ("DLSW-MIB", "dlswDirNBNameType"), ("DLSW-MIB", "dlswDirNBEntryType"), ("DLSW-MIB", "dlswDirNBLocationType"), ("DLSW-MIB", "dlswDirNBLocation"), ("DLSW-MIB", "dlswDirNBStatus"), ("DLSW-MIB", "dlswDirNBLFSize"), ("DLSW-MIB", "dlswDirNBRowStatus"),))
if mibBuilder.loadTexts: dlswDirNBGroup.setDescription('Conformance group for DLSw directory using NetBIOS\n        names.')
dlswDirLocateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 12)).setObjects(*(("DLSW-MIB", "dlswDirLocateMacLocation"),))
if mibBuilder.loadTexts: dlswDirLocateGroup.setDescription('Conformance group for a node that can return directory\n        entry order for a given MAC address.')
dlswDirLocateNBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 13)).setObjects(*(("DLSW-MIB", "dlswDirLocateNBLocation"),))
if mibBuilder.loadTexts: dlswDirLocateNBGroup.setDescription('Conformance group for a node that can return directory\n        entry order for a given NetBIOS name.')
dlswCircuitStatGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 14)).setObjects(*(("DLSW-MIB", "dlswCircuitStatActives"), ("DLSW-MIB", "dlswCircuitStatCreates"),))
if mibBuilder.loadTexts: dlswCircuitStatGroup.setDescription('Conformance group for statistics about circuits.')
dlswCircuitGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 15)).setObjects(*(("DLSW-MIB", "dlswCircuitS1IfIndex"), ("DLSW-MIB", "dlswCircuitS1DlcType"), ("DLSW-MIB", "dlswCircuitS1RouteInfo"), ("DLSW-MIB", "dlswCircuitS1CircuitId"), ("DLSW-MIB", "dlswCircuitS1Dlc"), ("DLSW-MIB", "dlswCircuitS2Location"), ("DLSW-MIB", "dlswCircuitS2TDomain"), ("DLSW-MIB", "dlswCircuitS2TAddress"), ("DLSW-MIB", "dlswCircuitS2CircuitId"), ("DLSW-MIB", "dlswCircuitOrigin"), ("DLSW-MIB", "dlswCircuitEntryTime"), ("DLSW-MIB", "dlswCircuitStateTime"), ("DLSW-MIB", "dlswCircuitState"), ("DLSW-MIB", "dlswCircuitPriority"), ("DLSW-MIB", "dlswCircuitFCSendGrantedUnits"), ("DLSW-MIB", "dlswCircuitFCSendCurrentWndw"), ("DLSW-MIB", "dlswCircuitFCRecvGrantedUnits"), ("DLSW-MIB", "dlswCircuitFCRecvCurrentWndw"), ("DLSW-MIB", "dlswCircuitFCLargestRecvGranted"), ("DLSW-MIB", "dlswCircuitFCLargestSendGranted"), ("DLSW-MIB", "dlswCircuitFCHalveWndwSents"), ("DLSW-MIB", "dlswCircuitFCResetOpSents"), ("DLSW-MIB", "dlswCircuitFCHalveWndwRcvds"), ("DLSW-MIB", "dlswCircuitFCResetOpRcvds"), ("DLSW-MIB", "dlswCircuitDiscReasonLocal"), ("DLSW-MIB", "dlswCircuitDiscReasonRemote"), ("DLSW-MIB", "dlswCircuitDiscReasonRemoteData"),))
if mibBuilder.loadTexts: dlswCircuitGroup.setDescription('Conformance group for DLSw circuits.')
dlswSdlcGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 16)).setObjects(*(("DLSW-MIB", "dlswSdlcLsEntries"), ("DLSW-MIB", "dlswSdlcLsLocalMac"), ("DLSW-MIB", "dlswSdlcLsLocalSap"), ("DLSW-MIB", "dlswSdlcLsLocalIdBlock"), ("DLSW-MIB", "dlswSdlcLsLocalIdNum"), ("DLSW-MIB", "dlswSdlcLsRemoteMac"), ("DLSW-MIB", "dlswSdlcLsRemoteSap"), ("DLSW-MIB", "dlswSdlcLsRowStatus"),))
if mibBuilder.loadTexts: dlswSdlcGroup.setDescription('Conformance group for DLSw SDLC support.')
dlswNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 46, 3, 2, 17)).setObjects(*(("DLSW-MIB", "dlswTrapTConnPartnerReject"), ("DLSW-MIB", "dlswTrapTConnProtViolation"), ("DLSW-MIB", "dlswTrapTConnUp"), ("DLSW-MIB", "dlswTrapTConnDown"), ("DLSW-MIB", "dlswTrapCircuitUp"), ("DLSW-MIB", "dlswTrapCircuitDown"),))
if mibBuilder.loadTexts: dlswNotificationGroup.setDescription('Conformance group for DLSw notifications.')
mibBuilder.exportSymbols("DLSW-MIB", dlswDirLocateNBGroup=dlswDirLocateNBGroup, dlswCircuitS1Dlc=dlswCircuitS1Dlc, dlswTConnConfigTable=dlswTConnConfigTable, dlswDirNBEntryType=dlswDirNBEntryType, dlswTConnTcpOperEntry=dlswTConnTcpOperEntry, dlswNodeVersion=dlswNodeVersion, dlswTConn=dlswTConn, dlswTConnOperPartnerSapList=dlswTConnOperPartnerSapList, dlswTConnStatCloseBusys=dlswTConnStatCloseBusys, dlswDirMacLFSize=dlswDirMacLFSize, dlswTConnStatActiveConnections=dlswTConnStatActiveConnections, dlswDirMacLocation=dlswDirMacLocation, dlswTConnConfigInitCirRecvWndw=dlswTConnConfigInitCirRecvWndw, dlswCircuitS2TDomain=dlswCircuitS2TDomain, dlswSdlcLsRemoteSap=dlswSdlcLsRemoteSap, dlswNodeVendorID=dlswNodeVendorID, dlswCircuitS2TAddress=dlswCircuitS2TAddress, dlswCircuitEntryTime=dlswCircuitEntryTime, dlswTConnOperPartnerInitPacingWndw=dlswTConnOperPartnerInitPacingWndw, dlswNodeNBGroup=dlswNodeNBGroup, dlswCircuitFCHalveWndwRcvds=dlswCircuitFCHalveWndwRcvds, dlswTConnStat=dlswTConnStat, dlswTConnOperPartnerMacExcl=dlswTConnOperPartnerMacExcl, dlswTrapCntlTConnPartnerReject=dlswTrapCntlTConnPartnerReject, dlswCircuitGroup=dlswCircuitGroup, dlswIfTable=dlswIfTable, EndStationLocation=EndStationLocation, dlswTConnStatCloseIdles=dlswTConnStatCloseIdles, dlswSdlcLsRowStatus=dlswSdlcLsRowStatus, dlswTConnOperDiscActiveCir=dlswTConnOperDiscActiveCir, dlswCircuitFCSendGrantedUnits=dlswCircuitFCSendGrantedUnits, dlswTConnOperDiscReason=dlswTConnOperDiscReason, dlswNodeUpTime=dlswNodeUpTime, dlswCircuitStatActives=dlswCircuitStatActives, dlswCircuitFCResetOpSents=dlswCircuitFCResetOpSents, dlswCoreCompliance=dlswCoreCompliance, dlswTConnOperNQexSents=dlswTConnOperNQexSents, dlswTConnSpecific=dlswTConnSpecific, dlswDirMacIndex=dlswDirMacIndex, DlswTCPAddress=DlswTCPAddress, dlswDirNBStatus=dlswDirNBStatus, dlswSdlcLsLocalSap=dlswSdlcLsLocalSap, DlcType=DlcType, dlswTConnOperLocalTAddr=dlswTConnOperLocalTAddr, dlswTConnStatGroup=dlswTConnStatGroup, dlswTConnOperGroup=dlswTConnOperGroup, dlswNodeStdPacingSupport=dlswNodeStdPacingSupport, dlswDirNBCacheMisses=dlswDirNBCacheMisses, dlswTrapCntlCircuit=dlswTrapCntlCircuit, MacAddressNC=MacAddressNC, dlswDirectory=dlswDirectory, dlswTConnOperRemoteTAddr=dlswTConnOperRemoteTAddr, dlswCircuitStatGroup=dlswCircuitStatGroup, dlswTConnOperConfigIndex=dlswTConnOperConfigIndex, dlswTConnOperPartnerNBExcl=dlswTConnOperPartnerNBExcl, dlswTConnOperCURexSents=dlswTConnOperCURexSents, dlswSdlc=dlswSdlc, dlswDirMacCacheHits=dlswDirMacCacheHits, PYSNMP_MODULE_ID=dlsw, dlswDirLocateMacEntry=dlswDirLocateMacEntry, dlswSdlcLsLocalIdBlock=dlswSdlcLsLocalIdBlock, dlsw=dlsw, dlswTrapTConnProtViolation=dlswTrapTConnProtViolation, dlswDirLocateMacMac=dlswDirLocateMacMac, dlswDirLocateMacMatch=dlswDirLocateMacMatch, dlswNodeVirtualSegmentLFSize=dlswNodeVirtualSegmentLFSize, dlswIfEntry=dlswIfEntry, dlswTConnOperPartnerVersion=dlswTConnOperPartnerVersion, dlswSdlcLsLocalIdNum=dlswSdlcLsLocalIdNum, dlswDirLocateNBLocation=dlswDirLocateNBLocation, dlswIfVirtualSegment=dlswIfVirtualSegment, dlswTrapCntlTConn=dlswTrapCntlTConn, dlswTConnConfigOpens=dlswTConnConfigOpens, dlswCircuitStat=dlswCircuitStat, dlswCircuitFCLargestRecvGranted=dlswCircuitFCLargestRecvGranted, dlswCircuitDiscReasonRemote=dlswCircuitDiscReasonRemote, dlswConformance=dlswConformance, dlswTConnOperDiscTime=dlswTConnOperDiscTime, dlswCircuitS1DlcType=dlswCircuitS1DlcType, dlswCircuitS1RouteInfo=dlswCircuitS1RouteInfo, dlswTConnOperFlowCntlMode=dlswTConnOperFlowCntlMode, dlswSdlcLsEntries=dlswSdlcLsEntries, dlswGroups=dlswGroups, dlswTConnTcpCompliance=dlswTConnTcpCompliance, dlswDirNBCacheNextIndex=dlswDirNBCacheNextIndex, dlswTConnTcpOperGroup=dlswTConnTcpOperGroup, TAddress=TAddress, dlswInterface=dlswInterface, dlswTConnOperNRexSents=dlswTConnOperNRexSents, dlswDirNBCacheHits=dlswDirNBCacheHits, dlswDirLocateMacTable=dlswDirLocateMacTable, dlswDirLocateCompliance=dlswDirLocateCompliance, dlswCircuitFCRecvCurrentWndw=dlswCircuitFCRecvCurrentWndw, dlswTConnTcpConfigTable=dlswTConnTcpConfigTable, dlswDirNBEntry=dlswDirNBEntry, dlswCircuit=dlswCircuit, dlswCircuitStateTime=dlswCircuitStateTime, dlswDirMacCacheMisses=dlswDirMacCacheMisses, dlswTConnOperOutCntlPkts=dlswTConnOperOutCntlPkts, dlswTConnOperInCntlPkts=dlswTConnOperInCntlPkts, dlswSdlcCompliance=dlswSdlcCompliance, dlswTrapTConnPartnerReject=dlswTrapTConnPartnerReject, dlswNodeGroup=dlswNodeGroup, dlswCircuitStatCreates=dlswCircuitStatCreates, dlswTConnOperOutDataPkts=dlswTConnOperOutDataPkts, dlswCircuitS1Mac=dlswCircuitS1Mac, dlswTConnTcpConfigKeepAliveInt=dlswTConnTcpConfigKeepAliveInt, dlswTConnTcpOperPrefTcpConnections=dlswTConnTcpOperPrefTcpConnections, dlswTConnOperPartnerMacInfo=dlswTConnOperPartnerMacInfo, dlswCircuitS2Sap=dlswCircuitS2Sap, dlswDirCache=dlswDirCache, dlswDirMacRowStatus=dlswDirMacRowStatus, dlswTConnConfigGroupDefinition=dlswTConnConfigGroupDefinition, dlswCircuitFCRecvGrantedUnits=dlswCircuitFCRecvGrantedUnits, dlswTConnOperCURexRcvds=dlswTConnOperCURexRcvds, dlswDirMacEntryType=dlswDirMacEntryType, dlswTrapControl=dlswTrapControl, dlswCircuitFCLargestSendGranted=dlswCircuitFCLargestSendGranted, dlswTrapCntlTConnProtViolation=dlswTrapCntlTConnProtViolation, dlswDirMacMask=dlswDirMacMask, dlswTConnNBGroup=dlswTConnNBGroup, dlswDirNBLFSize=dlswDirNBLFSize, dlswTConnConfigEntry=dlswTConnConfigEntry, dlswTConnConfigIndex=dlswTConnConfigIndex, dlswTConnOperPartnerVersionStr=dlswTConnOperPartnerVersionStr, dlswNodeStatus=dlswNodeStatus, dlswDirNBLocationType=dlswDirNBLocationType, dlswCircuitS2CircuitId=dlswCircuitS2CircuitId, dlswTraps=dlswTraps, dlswNotificationGroup=dlswNotificationGroup, dlswTConnTcpConfigEntry=dlswTConnTcpConfigEntry, dlswTConnConfigTDomain=dlswTConnConfigTDomain, dlswSdlcLsEntry=dlswSdlcLsEntry, dlswTConnTcp=dlswTConnTcp, dlswCircuitS1IfIndex=dlswCircuitS1IfIndex, dlswDirCompliance=dlswDirCompliance, dlswDirLocateNBEntry=dlswDirLocateNBEntry, dlswDirStat=dlswDirStat, dlswDirMacEntries=dlswDirMacEntries, dlswTConnOperNQexRcvds=dlswTConnOperNQexRcvds, dlswSdlcGroup=dlswSdlcGroup, dlswTConnTcpConfigGroup=dlswTConnTcpConfigGroup, dlswTConnConfigSapList=dlswTConnConfigSapList, dlswTConnOperTDomain=dlswTConnOperTDomain, dlswCircuitS2Mac=dlswCircuitS2Mac, dlswTConnOperInDataOctets=dlswTConnOperInDataOctets, dlswCircuitFCResetOpRcvds=dlswCircuitFCResetOpRcvds, dlswTrapTConnUp=dlswTrapTConnUp, dlswDirMacLocationType=dlswDirMacLocationType, dlswDirLocate=dlswDirLocate, null=null, dlswDirGroup=dlswDirGroup, dlswTrapTConnDown=dlswTrapTConnDown, dlswTConnConfigRemoteTAddr=dlswTConnConfigRemoteTAddr, dlswDirLocateNBName=dlswDirLocateNBName, dlswCircuitS1CircuitId=dlswCircuitS1CircuitId, dlswTConnOperPartnerVendorID=dlswTConnOperPartnerVendorID, dlswTConnOperPartnerNBInfo=dlswTConnOperPartnerNBInfo, dlswTConnOperICRexRcvds=dlswTConnOperICRexRcvds, dlswTConnOperCirCreates=dlswTConnOperCirCreates, dlswTConnTcpOperKeepAliveInt=dlswTConnTcpOperKeepAliveInt, dlswDirNBIndex=dlswDirNBIndex, dlswCircuitState=dlswCircuitState, dlswTConnTcpConfigTcpConnections=dlswTConnTcpConfigTcpConnections, dlswTrapCircuitUp=dlswTrapCircuitUp, dlswCompliances=dlswCompliances, dlswTConnOperConnectTime=dlswTConnOperConnectTime, dlswTrapCircuitDown=dlswTrapCircuitDown, dlswDomains=dlswDomains, dlswDirLocateNBMatch=dlswDirLocateNBMatch, dlswTConnOperNRexRcvds=dlswTConnOperNRexRcvds, dlswTConnConfigLocalTAddr=dlswTConnConfigLocalTAddr, LFSize=LFSize, dlswTConnOperEntry=dlswTConnOperEntry, dlswIfSapList=dlswIfSapList, dlswTConnConfigSetupType=dlswTConnConfigSetupType, dlswIfRowStatus=dlswIfRowStatus, dlswDirMacEntry=dlswDirMacEntry, dlswTConnTcpOperTcpConnections=dlswTConnTcpOperTcpConnections, dlswDirMacMac=dlswDirMacMac, dlswTConnTcpConfigMaxSegmentSize=dlswTConnTcpConfigMaxSegmentSize, dlswNode=dlswNode, dlswSdlcLsTable=dlswSdlcLsTable, dlswTConnOperTable=dlswTConnOperTable, dlswTConnOperOutDataOctets=dlswTConnOperOutDataOctets, dlswDirMacCacheNextIndex=dlswDirMacCacheNextIndex, dlswDirNBTable=dlswDirNBTable, dlswTConnTcpOperTable=dlswTConnTcpOperTable, dlswTConnOperICRexSents=dlswTConnOperICRexSents, dlswTConnOperCircuits=dlswTConnOperCircuits, dlswDirNBEntries=dlswDirNBEntries, dlswDirMacTable=dlswDirMacTable, dlswTConnOperEntryTime=dlswTConnOperEntryTime, dlswCircuitS2Location=dlswCircuitS2Location, dlswCircuitDiscReasonLocal=dlswCircuitDiscReasonLocal, dlswDirNBRowStatus=dlswDirNBRowStatus, dlswCircuitS1Sap=dlswCircuitS1Sap, dlswCircuitEntry=dlswCircuitEntry, dlswDirLocateNBTable=dlswDirLocateNBTable, dlswDirNBLocation=dlswDirNBLocation, dlswNodeVersionString=dlswNodeVersionString, dlswCircuitPriority=dlswCircuitPriority, dlswTConnOperState=dlswTConnOperState, dlswTConnConfigGroup=dlswTConnConfigGroup, dlswDirNBName=dlswDirNBName, dlswDirNBGroup=dlswDirNBGroup, dlswNodeResourceNBExclusivity=dlswNodeResourceNBExclusivity, dlswSdlcLsLocalMac=dlswSdlcLsLocalMac, dlswDirNBNameType=dlswDirNBNameType, dlswCircuitTable=dlswCircuitTable, dlswTConnConfigEntryType=dlswTConnConfigEntryType, dlswTConnConfigAdvertiseMacNB=dlswTConnConfigAdvertiseMacNB, dlswCircuitFCSendCurrentWndw=dlswCircuitFCSendCurrentWndw, dlswCircuitOrigin=dlswCircuitOrigin, dlswDirLocateGroup=dlswDirLocateGroup, dlswTCPDomain=dlswTCPDomain, dlswNodeResourceMacExclusivity=dlswNodeResourceMacExclusivity, dlswDirMacStatus=dlswDirMacStatus, dlswSdlcLsRemoteMac=dlswSdlcLsRemoteMac, dlswTConnConfigLastModifyTime=dlswTConnConfigLastModifyTime, dlswInterfaceGroup=dlswInterfaceGroup, dlswCircuitFCHalveWndwSents=dlswCircuitFCHalveWndwSents, dlswMIB=dlswMIB, dlswTConnOperInDataPkts=dlswTConnOperInDataPkts, dlswDirLocateMacLocation=dlswDirLocateMacLocation, NBName=NBName, dlswTConnConfigRowStatus=dlswTConnConfigRowStatus, dlswCircuitDiscReasonRemoteData=dlswCircuitDiscReasonRemoteData)
